using System;
using System.Collections.Generic;
using System.Text;
using Microsoft.Practices.CompositeUI;
using Microsoft.Practices.CompositeUI.EventBroker;

namespace AddressBookModule
{
    public class AddBookController : Controller
    {
        DictionaryEventArgs args;

        [EventPublication("event://AddressBook/addEntry", PublicationScope.Global)]
        public event EventHandler addEntry;

        public void AddNewEntry(string name, string jobTitle, string company, string email, string displayName, string webPage, string business, string home, string mobile, string address)
        {           
            addEntry(this, SetArgs(name, jobTitle, company, email, displayName, webPage, business, home, mobile, address));
        }

        [EventPublication("event://AddressBook/editEntry", PublicationScope.Global)]
        public event EventHandler editEntry;

        public void EditExistingEntry(string name, string jobTitle, string company, string email, string displayName, string webPage, string business, string home, string mobile, string address)
        {
            editEntry(this, SetArgs(name, jobTitle, company, email, displayName, webPage, business, home, mobile, address));            
        }

        [EventPublication("event://AddressBook/loadEntries", PublicationScope.Global)]
        public event EventHandler loadEntries;

        public void LoadEntries()
        {
            loadEntries(this, new DictionaryEventArgs());
        }

        [EventPublication("event://AddressBook/deleteEntry", PublicationScope.Global)]
        public event EventHandler deleteEntry;

        public void DeleteEntry(string name)
        {
            DictionaryEventArgs args = new DictionaryEventArgs();

            args.Data["Name"] = name;
            deleteEntry(this, args);
        }

        [EventPublication("event://AddressBook/loadSingleEntry", PublicationScope.Global)]
        public event EventHandler loadSingleEntry;

        public string[] LoadSingleEntry(string name)
        {
            loadSingleEntry(this, SetArgs(name, null, null, null,null, null, null, null, null, null));

            string[] info = new string[10];
            info[0] = args.Data["Title"].ToString();
            info[1] = args.Data["Company"].ToString();
            info[2] = args.Data["Email"].ToString();
            info[3] = args.Data["Display"].ToString();
            info[4] = args.Data["WebPage"].ToString();
            info[5] = args.Data["Business"].ToString();
            info[6] = args.Data["Home"].ToString();
            info[7] = args.Data["Mobile"].ToString();
            info[8] = args.Data["Address"].ToString();
            info[9] = name;
            return info;
        }

        private DictionaryEventArgs SetArgs(string name, string jobTitle, string company, string email, string displayName, string webPage, string business, string home, string mobile, string address)
        {
            args = new DictionaryEventArgs();

            args.Data["Name"] = name;
            args.Data["Title"] = jobTitle;
            args.Data["Company"] = company;
            args.Data["Email"] = email;
            args.Data["Display"] = displayName;
            args.Data["WebPage"] = webPage;
            args.Data["Business"] = business;
            args.Data["Home"] = home;
            args.Data["Mobile"] = mobile;
            args.Data["Address"] = address;

            return args;
        }
    }
}
