using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Text;
using System.Windows.Forms;
using Microsoft.Practices.CompositeUI;
using Microsoft.Practices.CompositeUI.Commands;
using Microsoft.Practices.ObjectBuilder;
using Microsoft.Practices.CompositeUI.EventBroker;

namespace AddressBookModule
{
    public partial class AddressBookEditorView : UserControl, IEditor
    {
        private AddBookController controller;

        [CreateNew]
        public AddBookController Controller
        {
            set
            {
                controller = value;
            }
        }
        
        public AddressBookEditorView()
        {
            InitializeComponent();
        }

        [CommandHandler("EntryAddNew")]
        public void OnAddNew_Click(object sender, EventArgs e)
        {
            //MessageBox.Show(cmbName.Text);
            this.controller.AddNewEntry(cmbName.Text, txtJobTitle.Text, txtCompany.Text, txtEmail.Text,
                txtDisplay.Text, txtWebPage.Text, txtBusiness.Text, txtHome.Text, txtMobile.Text, txtAddress.Text);
            this.cmbName.Items.Clear();
            DataCollection infoCollection = new DataCollection();
            this.NameCollection = infoCollection.GetContacts("sp_get_Name", "");
        }

        [CommandHandler("EntryEdit")]
        public void OnEdit_Click(object sender, EventArgs e)
        {
            this.controller.EditExistingEntry(cmbName.Text, txtJobTitle.Text, txtCompany.Text, txtEmail.Text,
                txtDisplay.Text, txtWebPage.Text, txtBusiness.Text, txtHome.Text, txtMobile.Text, txtAddress.Text);
        }

        [CommandHandler("EntryClear")]
        public void OnClear_Click(object sender, EventArgs e)
        {
            ClearFields();
            this.cmbName.Text = "";
        }

        [CommandHandler("EntryDelete")]
        public void OnDelete_Click(object sender, EventArgs e)
        {
            this.controller.DeleteEntry(txtName.Text);
            this.ClearFields();
            this.cmbName.Text = "";
            this.cmbName.Focus();
        }

        private void AddressBookEditorView_Load(object sender, EventArgs e)
        {
            this.controller.LoadEntries();
        }

        private void ClearFields()
        {
            this.txtName.Text = "";
            this.txtJobTitle.Text = "";
            this.txtCompany.Text = "";
            this.txtBusiness.Text = "";
            this.txtHome.Text = "";
            this.txtMobile.Text = "";
            this.txtEmail.Text = "";
            this.txtDisplay.Text = "";
            this.txtWebPage.Text = "";
            this.txtAddress.Text = "";
        }      

        private void GetSingleContactDetails(string name)
        {
            if (name != null || name != "")
            {
                DataCollection infoCollection = new DataCollection();
                if (infoCollection.CheckExists(name))
                {
                    string[] info = this.controller.LoadSingleEntry(name);
                    txtJobTitle.Text = info[0];
                    txtCompany.Text = info[1];
                    txtEmail.Text = info[2];
                    txtDisplay.Text = info[3];
                    txtWebPage.Text = info[4];
                    txtBusiness.Text = info[5];
                    txtHome.Text = info[6];
                    txtMobile.Text = info[7];
                    txtAddress.Text = info[8];
                    txtName.Text = info[9];
                    this.cmbName.Text = name;
                }
                else
                {
                    ClearFields();
                }
            }
        }


        #region IEditor Members


        public DataTable NameCollection
        {
            set 
            {
                DataTable dataTable = value;
                foreach (DataRow row in dataTable.Rows)
                {
                    this.cmbName.Items.Add(row[0]);
                }                
            }
        }

        #endregion

        private void cmbName_SelectedIndexChanged(object sender, EventArgs e)
        {
            //GetSingleContactDetails();
        }

        private void cmbName_Leave(object sender, EventArgs e)
        {
            GetSingleContactDetails(cmbName.Text);
        }

        private void cmbName_KeyUp(object sender, KeyEventArgs e)
        {
            if (e.KeyCode == Keys.Tab || e.KeyCode == Keys.Enter)
            {
                GetSingleContactDetails(cmbName.Text);
            }
        }

        [EventSubscription("events://AddressBook/selectEntry", Thread = ThreadOption.UserInterface)]
        public void select(object sender, DictionaryEventArgs args)
        {
            GetSingleContactDetails(args.Data["Name"].ToString());
        }
    }
}
