using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Text;
using System.Windows.Forms;
using Microsoft.Practices.CompositeUI;
using Microsoft.Practices.CompositeUI.EventBroker;
using Microsoft.Practices.ObjectBuilder;


namespace AddressBookModule
{
    public partial class AddressBookListView : UserControl
    {
        DataCollection infoCollection;

        AddBookListController listController;

        string address;
        string business;
        string company;
        string displayName;
        string email;
        string home;
        string jobTitle;
        string mobile;
        string name;
        string webPage;
        

        public AddressBookListView()
        {
            InitializeComponent();
        }

        [CreateNew]
        public AddBookListController ListController
        {
            set
            {
                listController = value;
            }
        }

        [EventSubscription("event://AddressBook/addEntry", Thread = ThreadOption.UserInterface)]
        public void AddContact(object sender, DictionaryEventArgs args)
        {
            infoCollection = new DataCollection();

            GetArgs(args);

            infoCollection.AddEditContact("sp_AddNewContact", name, jobTitle, company, email, displayName, webPage, business, home, mobile, address, "Add");
            this.gridGroupingControl1.DataSource = infoCollection.GetContacts("sp_GetContacts", "");
            this.gridGroupingControl1.Refresh();

        }

        [EventSubscription("event://AddressBook/editEntry", Thread = ThreadOption.UserInterface)]
        public void EditContact(object sender, DictionaryEventArgs args)
        {
            infoCollection = new DataCollection();
            GetArgs(args);

            infoCollection.AddEditContact("sp_EditContact", name, jobTitle, company, email, displayName, webPage, business, home, mobile, address, "Edit");
            this.gridGroupingControl1.DataSource = infoCollection.GetContacts("sp_GetContacts", "");
            this.gridGroupingControl1.Refresh();
        }

        [EventSubscription("event://AddressBook/loadEntries", Thread = ThreadOption.UserInterface)]
        public void LoadContacts(object sender, DictionaryEventArgs args)
        {
            infoCollection = new DataCollection();
            this.gridGroupingControl1.DataSource = infoCollection.GetContacts("sp_GetContacts", "");
            this.gridGroupingControl1.Refresh();
        }

        [EventSubscription("event://AddressBook/deleteEntry", Thread = ThreadOption.UserInterface)]
        public void DeleteContact(object sender, DictionaryEventArgs args)
        {
            infoCollection = new DataCollection();
            name = args.Data["Name"].ToString();
            infoCollection.DeleteContact(name);

            this.gridGroupingControl1.DataSource = infoCollection.GetContacts("sp_GetContacts", "");
            this.gridGroupingControl1.Refresh();
        }       
        
        [EventSubscription("event://AddressBook/loadSingleEntry", Thread = ThreadOption.UserInterface)]
        public void SelectContact(object sender, DictionaryEventArgs args)
        {
            infoCollection = new DataCollection();
            string[] info = new string[9];
            DataTable dataTable = infoCollection.GetContacts("sp_SelectContact", args.Data["Name"].ToString());
            DataRow row = dataTable.Rows[0];//infoCollection.GetInfo(args.Data["Name"].ToString());
                        
            args.Data["Title"] = row[0];
            args.Data["Company"] = row[1];
            args.Data["Email"] = row[2];
            args.Data["Display"] = row[3];
            args.Data["WebPage"] = row[4];
            args.Data["Business"] = row[5];
            args.Data["Home"] = row[6];
            args.Data["Mobile"] = row[7];
            args.Data["Address"] = row[8];            
        }

        private void GetArgs(DictionaryEventArgs args)
        {
            name = args.Data["Name"].ToString();
            jobTitle = args.Data["Title"].ToString();
            company = args.Data["Company"].ToString();
            email = args.Data["Email"].ToString();
            displayName = args.Data["Display"].ToString();
            webPage = args.Data["WebPage"].ToString();
            business = args.Data["Business"].ToString();
            home = args.Data["Home"].ToString();
            mobile = args.Data["Mobile"].ToString();
            address = args.Data["Address"].ToString();
        }

        private void gridGroupingControl1_QueryCellStyleInfo(object sender, Syncfusion.Windows.Forms.Grid.Grouping.GridTableCellStyleInfoEventArgs e)
        {
            e.Style.ReadOnly = true;
        }      

        private void gridGroupingControl1_SelectedRecordsChanged(object sender, Syncfusion.Grouping.SelectedRecordsChangedEventArgs e)
        {
            if (e.SelectedRecord != null)
            {           

                Syncfusion.Grouping.Record record = e.SelectedRecord.Record;//this.gridGroupingControl1.Table.Records[id];

                int index = this.gridGroupingControl1.Table.Records.IndexOf(record);

                DataRowView rowView = record.GetData() as DataRowView;

                DataRow row = rowView.Row;

                this.listController.SelectEntry(row[0].ToString());     
                
            }
        }
    }
}
