using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using Microsoft.Practices.CompositeUI;
using Microsoft.Practices.CompositeUI.Commands;
using Microsoft.Practices.CompositeUI.SmartParts;
using Microsoft.Practices.CompositeUI.Utility;
using Syncfusion.Windows.Forms.Tools;

namespace SampleAddressBook
{
    [SmartPart]
    public class customPanel : IComposableWorkspace<Control, CustomSPI>
    {
        private WorkspaceComposer<Control, CustomSPI> composer;        
        private string name;        

        public customPanel()
        {
            composer = new WorkspaceComposer<Control, CustomSPI>(this);           
        }

        [ServiceDependency]
        public WorkItem workItem
        {
            set
            {
                composer.WorkItem = value;
            }
        }

        public string Name
        {
            get
            {
                return name;
            }
            set
            {
                name = value;
            }
        }

        private void ControlDisposed(object sender, EventArgs e)
        {
            UserControl control = sender as UserControl;
            if (control != null)
            {
                composer.ForceClose(control);
            }
        }

        protected virtual void OnActivateSmartPart(UserControl smartPart)
        {
            smartPart.BringToFront();
            smartPart.Show();
        }

        protected virtual void OnApplySmartPartInfoSmartPart(Control smartPart, SmartPartInfo smartPartInfo)
        {

        }

        protected virtual void OnCloseSmartPart(UserControl smartPart)
        {
            //this.SetEnableDocking(smartPart, false);
            //this.DockControl(smartPart, smartPart.Parent, DockingStyle.Top, 150);
            //this.Controls.Remove(smartPart);
            smartPart.Disposed -= ControlDisposed;           

        }

        protected virtual void OnHideSmartPart(UserControl smartPart)
        {
            smartPart.Hide();
        }

        protected virtual void OnShowSmartPart(UserControl smartPart, CustomSPI smartPartInfo)
        {
            smartPart.Dock = DockStyle.Fill;
            //this.DockControl(smartPart, smartPart.Parent, DockingStyle.Top, 150);
            //this.SetDockLabel(smartPart, "My Panel");
            //this.Controls.Add(smartPart);

            smartPart.Disposed += ControlDisposed;
            Activate(smartPart);
        }

        protected virtual void OnSmartPartActivated(WorkspaceEventArgs e)
        {
            if (SmartPartActivated != null)
            {
                SmartPartActivated(this, e);
            }
        }

        protected virtual void OnSmartPartClosing(WorkspaceCancelEventArgs e)
        {
            if (SmartPartClosing != null)
            {
                SmartPartClosing(this, e);
            }
        }

        #region IComposableWorkspace<Control,CustomSPI> Members

        public CustomSPI ConvertFrom(ISmartPartInfo source)
        {
            return SmartPartInfo.ConvertTo<CustomSPI>(source);
        }

        public void OnActivate(Control smartPart)
        {
            OnActivateSmartPart((UserControl)smartPart);
        }

        public void OnApplySmartPartInfo(Control smartPart, CustomSPI smartPartInfo)
        {
            OnApplySmartPartInfoSmartPart(smartPart, smartPartInfo);
        }

        public void OnClose(Control smartPart)
        {
            OnCloseSmartPart((UserControl)smartPart);
        }

        public void OnHide(Control smartPart)
        {
            OnHideSmartPart((UserControl)smartPart);
        }

        public void OnShow(Control smartPart, CustomSPI smartPartInfo)
        {
            OnShowSmartPart((UserControl)smartPart, smartPartInfo);
        }       

        public void RaiseSmartPartActivated(WorkspaceEventArgs e)
        {
            OnSmartPartActivated(e);
        }

        public void RaiseSmartPartClosing(WorkspaceCancelEventArgs e)
        {
            OnSmartPartClosing(e);
        }

        #endregion

        #region IWorkspace Members

        public void Activate(object smartPart)
        {
            composer.Activate(smartPart);
        }

        public object ActiveSmartPart
        {
            get { return composer.ActiveSmartPart; }
        }

        public void ApplySmartPartInfo(object smartPart, ISmartPartInfo smartPartInfo)
        {
            composer.ApplySmartPartInfo(smartPart, smartPartInfo);
        }

        public void Close(object smartPart)
        {
            composer.Close(smartPart);
        }

        public void Hide(object smartPart)
        {
            composer.Hide(smartPart);
        }

        public void Show(object smartPart)
        {
            composer.Show(smartPart);
        }

        public void Show(object smartPart, ISmartPartInfo smartPartInfo)
        {
            composer.Show(smartPart, smartPartInfo);
        }

        public event EventHandler<WorkspaceEventArgs> SmartPartActivated;

        public event EventHandler<WorkspaceCancelEventArgs> SmartPartClosing;

        [Browsable(false)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        public System.Collections.ObjectModel.ReadOnlyCollection<object> SmartParts
        {
            get { return composer.SmartParts; }
        }

        #endregion
    }
}